@@ -160,10 +160,14 @@ class OflyService(Request):
         signature_base_string = \
             self.consumer_secret \
             + url_path \
-            + '?' \
-            + self._sort_params(params) \
-            + '&' \
-            + self._sort_params(ofly_params)
+            + '?'
+
+        # only append params if there are any, to avoid a leading ampersand
+        sorted_params = self._sort_params(params)
+        if len(sorted_params) > 0:
+            signature_base_string += sorted_params + '&'
+
+        signature_base_string += self._sort_params(ofly_params)
 
         params['oflyApiSig'] = hashlib.sha1(signature_base_string).hexdigest()
 
@@ -202,13 +206,15 @@ class OflyService(Request):
         :param header_auth: Authenication via header, defaults to False.
         :param \*\*kwargs: Optional arguments. Same as Requests.
         '''
-        params = kwargs.get('params')
-        data = kwargs.get('data')
+        params = kwargs.pop('params', None)
+        data = kwargs.pop('data', None)
 
         if params is None:
             params = {}
 
-        header_auth = kwargs.get('header_auth', False)
+        kwargs['timeout'] = kwargs.get('timeout', 300)
+
+        header_auth = kwargs.pop('header_auth', False)
         if header_auth:
             params, headers = self._sha1_sign_params(url,
                                                      header_auth,
@@ -216,13 +222,15 @@ class OflyService(Request):
 
             response = self.session.request(method,
                                             url + '?' + params,
-                                            headers=headers)
+                                            headers=headers,
+                                            **kwargs)
         else:
             params = self._sha1_sign_params(url, **params)
 
             response = self.session.request(method,
                                             url + '?' + params,
-                                            data=data)
+                                            data=data,
+                                            **kwargs)
 
         return Response(response)
 
@@ -335,6 +343,7 @@ class OAuth2Service(Request):
         :param url: The resource to be requested.
         :param \*\*kwargs: Optional arguments. Same as Requests.
         '''
+        kwargs['timeout'] = kwargs.get('timeout', 300)
         response = self.session.request(method, url, **kwargs)
         return Response(response)
 
@@ -374,9 +383,9 @@ class OAuth1Service(Request):
                                      request_token=request_token,
                                      request_token_secret=request_token_secret)
 
-        # access tokens are returned in the response dictionary
-        response['oauth_token']
-        response['oauth_key']
+        # access tokens are returned in the response.content dictionary
+        response.content['oauth_token']
+        response.content['oauth_key']
 
     Finally the :class:`get_authenticated_session` method returns a wrapped
     session and can be used once the access token has been made available.
@@ -523,6 +532,18 @@ class OAuth1Service(Request):
         access_token_secret = kwargs.pop('access_token_secret')
         header_auth = kwargs.pop('header_auth', self.header_auth)
         allow_redirects = kwargs.pop('allow_redirects', True)
+
+        kwargs['headers'] = kwargs.get('headers', {})
+
+        # set a default request timeout
+        kwargs['timeout'] = kwargs.get('timeout', 300)
+
+        # set the Content-Type if unspecified
+        if method in ('POST', 'PUT'):
+            kwargs['headers']['Content-Type'] = \
+                kwargs['headers'].get('Content-Type',
+                                      'application/x-www-form-urlencoded')
+
         auth_session = \
             self._construct_session(access_token=access_token,
                                     access_token_secret=access_token_secret,
